ports/databases/pgbarman/files/patch-barman_config.py
Matthew Seaman 6b90d782ff databases/pgbarman: update to 3.12.0
Rework patches after upstream changes to the layout of documentation
sources.  Note PGUSER is now redundant, as all supported postgresql
ports use `postgres` as the name of the database owner.

Changes:	https://github.com/EnterpriseDB/barman/blob/release/3.12.0/RELNOTES.md
Reported by:	portscout, repology
2024-11-23 12:25:11 +00:00

22 lines
709 B
Python

--- barman/config.py.orig 2024-11-23 11:42:48 UTC
+++ barman/config.py
@@ -1194,15 +1194,15 @@ class Config(object):
class Config(object):
"""This class represents the barman configuration.
- Default configuration files are /etc/barman.conf,
- /etc/barman/barman.conf
+ Default configuration files are %%PREFIX%%/etc/barman.conf,
+ %%PREFIX%%/etc/barman/barman.conf
and ~/.barman.conf for a per-user configuration
"""
CONFIG_FILES = [
"~/.barman.conf",
- "/etc/barman.conf",
- "/etc/barman/barman.conf",
+ "%%PREFIX%%/etc/barman.conf",
+ "%%PREFIX%%/etc/barman/barman.conf",
]
_QUOTE_RE = re.compile(r"""^(["'])(.*)\1$""")